==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/listlevel/ListLevelStyleNumber.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyriListLevelStyleNumberght of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.listlevel;

import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.properties.TextProperties;
import com.openexchange.office.filter.odf.styles.StyleManager;
import com.openexchange.office.filter.odf.styles.TextListStyle;

public class ListLevelStyleNumber extends ListLevelStyleEntry {

	public ListLevelStyleNumber(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public ListLevelStyleNumber clone() {
		return (ListLevelStyleNumber)super._clone();
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
		//
	}

	@Override
    public void createPresentationAttrs(StyleManager styleManager, String listStyleType, boolean contentAutoStyle, OpAttrs paragraphAttrs) {
        final OpAttrs bullet = paragraphAttrs.getMap("bullet", true);
        final String numType = TextListStyle.getNumberFormat(this);
        if(numType.equals("none")) {
            bullet.put("type", "none");
        }
        else {
            bullet.put("type", "numbering");

            final String numFormat = attributes.getValue("style:num-format");
            final String numSuffix = attributes.getValue("style:num-suffix");
            final String numPrefix = attributes.getValue("style:num-prefix");

            final String destFormat;
            switch(getPrefix(numPrefix) + getNumFormat(numFormat) + getSuffix(numSuffix)) {
            	case "a.":  destFormat = "alphaLcPeriod"; break;
            	case "a":
            	case "a)":  destFormat = "alphaLcParenR"; break;
            	case "(a)": destFormat = "alphaLcParenBoth"; break;
            	case "A.":  destFormat = "alphaUcPeriod"; break;
            	case "A":
            	case "A)":  destFormat = "alphaUcParenR"; break;
            	case "(A)": destFormat = "alphaUcParenBoth"; break;
            	case "i.":  destFormat = "romanLcPeriod"; break;
            	case "i":
            	case "i)":  destFormat = "romanLcParenR"; break;
            	case "(i)": destFormat = "romanLcParenBoth"; break;
            	case "I.":  destFormat = "romanUcPeriod"; break;
            	case "I":
            	case "I)":  destFormat = "romanUcParenR"; break;
            	case "(I)": destFormat = "romanUcParenBoth"; break;
            	case "1.":  destFormat =  "arabicPeriod"; break;
            	case "1":
            	case "1)":
            	default:	destFormat = "arabicParenR"; break;
            	case "(1)": destFormat = "arabicParenBoth"; break;
            }
            bullet.put("numType", destFormat);

            final String startValue = getAttribute("text:start-value");
            if (startValue!=null) {
                bullet.put("startAt", Integer.parseInt(startValue));
            }
        }
        super.createPresentationAttrs(styleManager, listStyleType, contentAutoStyle, paragraphAttrs);
    }

	private String getNumFormat(String s) {
		final String numFormat = getFirstChar(s);
		return numFormat.equals("1")||numFormat.equals("a")||numFormat.equals("A")||numFormat.equals("i")||numFormat.equals("I") ? numFormat : "1";
	}

	private String getPrefix(String s) {
		final String prefix = getFirstChar(s);
		return prefix.isEmpty()||prefix.equals("(") ? prefix : "";
	}

	private String getSuffix(String s) {
		final String suffix = getFirstChar(s);
		return suffix.isEmpty()||suffix.equals(".")||suffix.equals(")") ? suffix : "";
	}

	private String getFirstChar(String s) {
		return s==null ? "" : s.isEmpty() ? "" : s.substring(0, 1);
	}

	@Override
    public void applyPresentationAttrs(StyleManager styleManager, JSONObject paragraphAttrs)
        throws JSONException {

	    final Object bulletAttrs = paragraphAttrs.opt("bullet");
	    if(bulletAttrs instanceof JSONObject) {
	        final String numType = ((JSONObject)bulletAttrs).optString("numType");
	        if(numType!=null) {
	            String numFormat = null;
	            String numSuffix = null;
	            String numPrefix = null;
	            switch(numType) {
	                case "alphaLcPeriod": {
	                    numFormat = "a";
	                    numSuffix = ".";
	                    break;
	                }
	                case "alphaLcParenR": {
	                    numFormat = "a";
	                    numSuffix = ")";
	                    break;
	                }
	                case "alphaLcParenBoth": {
	                    numFormat = "a";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "alphaUcPeriod": {
	                    numFormat = "A";
	                    numSuffix = ".";
	                    break;
	                }
	                case "alphaUcParenR": {
	                    numFormat = "A";
	                    numSuffix = ")";
	                    break;
	                }
	                case "alphaUcParenBoth": {
	                    numFormat = "A";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "romanLcPeriod": {
	                    numFormat = "i";
	                    numSuffix = ".";
	                    break;
	                }
	                case "romanLcParenR": {
	                    numFormat = "i";
	                    numSuffix = ")";
	                    break;
	                }
	                case "romanLcParenBoth": {
	                    numFormat = "i";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "romanUcPeriod": {
	                    numFormat = "I";
	                    numSuffix = ".";
	                    break;
	                }
	                case "romanUcParenR": {
	                    numFormat = "I";
	                    numSuffix = ")";
	                    break;
	                }
	                case "romanUcParenBoth": {
	                    numFormat = "I";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "arabicPeriod": {
	                    numFormat = "1";
	                    numSuffix = ".";
	                    break;
	                }
	                case "arabicParenR": {
	                    numFormat = "1";
	                    numSuffix = ")";
	                    break;
	                }
	                case "arabicParenBoth": {
	                    numFormat = "1";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "noNumberListItem": {
	                    break;
	                }
	            }
	            if(numFormat!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-format", "style:num-format", numFormat);
	            }
	            if(numSuffix!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-suffix", "style:num-suffix", numSuffix);
	            }
	            if(numPrefix!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-prefix", "style:num-prefix", numPrefix);
	            }
	        }
	        final Object startAt = ((JSONObject)bulletAttrs).opt("startAt");
	        if(startAt!=null) {
    	        if(startAt instanceof Number) {
    	            attributes.setIntValue(Namespaces.TEXT, "start-value", "text:start-value",  ((Number)startAt).intValue());
    	        }
    	        else {
    	            attributes.remove("text:start-value");
    	        }
	        }
	    }
        final Object bulletSizeAttrs = paragraphAttrs.opt("bulletSize");
        if(bulletSizeAttrs!=null) {
            if(bulletSizeAttrs instanceof JSONObject) {
                final String type = ((JSONObject)bulletSizeAttrs).optString("type");
                if("percent".equals(type)) {
                    final Object buSize = ((JSONObject)bulletSizeAttrs).opt("size");
                    if(buSize!=null) {
                        if(buSize instanceof Number) {
                            getTextProperties(true).getAttributes().setValue(Namespaces.FO, "font-size", "fo:font-size", Integer.toString(((Number)buSize).intValue())+"%");
                        }
                        else {
                            getTextProperties(true).getAttributes().remove("fo:font-size");
                        }
                    }
                }
            }
            else {
                attributes.remove("fo:font-size");
                // TODO what is "text:bullet-relative-size");
            }
        }
        super.applyPresentationAttrs(styleManager, paragraphAttrs);
    }

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
        final Integer listLevel = getListLevel(0);
		if(listLevel>=1&&listLevel<=10) {
			TextListStyle.createListLevelDefinition(this, attrs, listLevel);
		}
	}

	@Override
	public String getQName() {
		return "text:list-level-style-number";
	}
	@Override
	public String getLocalName() {
		return "list-level-style-number";
	}

	@Override
	public String getNamespace() {
		return Namespaces.TEXT;
	}
}

==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/listlevel/ListLevelStyleNumber.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyriListLevelStyleNumberght of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.listlevel;

import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.office.filter.api.OCKey;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.styles.StyleManager;
import com.openexchange.office.filter.odf.styles.TextListStyle;

public class ListLevelStyleNumber extends ListLevelStyleEntry {

	public ListLevelStyleNumber(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public ListLevelStyleNumber clone() {
		return (ListLevelStyleNumber)super._clone();
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
		//
	}

	@Override
    public void createPresentationAttrs(StyleManager styleManager, String listStyleType, boolean contentAutoStyle, OpAttrs paragraphAttrs) {
        final OpAttrs bullet = paragraphAttrs.getMap(OCKey.BULLET.value(), true);
        final String numType = TextListStyle.getNumberFormat(this);
        if(numType.equals("none")) {
            bullet.put(OCKey.TYPE.value(), "none");
        }
        else {
            bullet.put(OCKey.TYPE.value(), "numbering");

            final String numFormat = attributes.getValue("style:num-format");
            final String numSuffix = attributes.getValue("style:num-suffix");
            final String numPrefix = attributes.getValue("style:num-prefix");

            final String destFormat;
            switch(getPrefix(numPrefix) + getNumFormat(numFormat) + getSuffix(numSuffix)) {
            	case "a.":  destFormat = "alphaLcPeriod"; break;
            	case "a":
            	case "a)":  destFormat = "alphaLcParenR"; break;
            	case "(a)": destFormat = "alphaLcParenBoth"; break;
            	case "A.":  destFormat = "alphaUcPeriod"; break;
            	case "A":
            	case "A)":  destFormat = "alphaUcParenR"; break;
            	case "(A)": destFormat = "alphaUcParenBoth"; break;
            	case "i.":  destFormat = "romanLcPeriod"; break;
            	case "i":
            	case "i)":  destFormat = "romanLcParenR"; break;
            	case "(i)": destFormat = "romanLcParenBoth"; break;
            	case "I.":  destFormat = "romanUcPeriod"; break;
            	case "I":
            	case "I)":  destFormat = "romanUcParenR"; break;
            	case "(I)": destFormat = "romanUcParenBoth"; break;
            	case "1.":  destFormat =  "arabicPeriod"; break;
            	case "1":
            	case "1)":
            	default:	destFormat = "arabicParenR"; break;
            	case "(1)": destFormat = "arabicParenBoth"; break;
            }
            bullet.put(OCKey.NUM_TYPE.value(), destFormat);

            final String startValue = getAttribute("text:start-value");
            if (startValue!=null) {
                bullet.put(OCKey.START_AT.value(), Integer.parseInt(startValue));
            }
        }
        super.createPresentationAttrs(styleManager, listStyleType, contentAutoStyle, paragraphAttrs);
    }

	private String getNumFormat(String s) {
		final String numFormat = getFirstChar(s);
		return numFormat.equals("1")||numFormat.equals("a")||numFormat.equals("A")||numFormat.equals("i")||numFormat.equals("I") ? numFormat : "1";
	}

	private String getPrefix(String s) {
		final String prefix = getFirstChar(s);
		return prefix.isEmpty()||prefix.equals("(") ? prefix : "";
	}

	private String getSuffix(String s) {
		final String suffix = getFirstChar(s);
		return suffix.isEmpty()||suffix.equals(".")||suffix.equals(")") ? suffix : "";
	}

	private String getFirstChar(String s) {
		return s==null ? "" : s.isEmpty() ? "" : s.substring(0, 1);
	}

	@Override
    public void applyPresentationAttrs(StyleManager styleManager, JSONObject paragraphAttrs)
        throws JSONException {

	    final Object bulletAttrs = paragraphAttrs.opt(OCKey.BULLET.value());
	    if(bulletAttrs instanceof JSONObject) {
	        final String numType = ((JSONObject)bulletAttrs).optString(OCKey.NUM_TYPE.value());
	        if(numType!=null) {
	            String numFormat = null;
	            String numSuffix = null;
	            String numPrefix = null;
	            switch(numType) {
	                case "alphaLcPeriod": {
	                    numFormat = "a";
	                    numSuffix = ".";
	                    break;
	                }
	                case "alphaLcParenR": {
	                    numFormat = "a";
	                    numSuffix = ")";
	                    break;
	                }
	                case "alphaLcParenBoth": {
	                    numFormat = "a";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "alphaUcPeriod": {
	                    numFormat = "A";
	                    numSuffix = ".";
	                    break;
	                }
	                case "alphaUcParenR": {
	                    numFormat = "A";
	                    numSuffix = ")";
	                    break;
	                }
	                case "alphaUcParenBoth": {
	                    numFormat = "A";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "romanLcPeriod": {
	                    numFormat = "i";
	                    numSuffix = ".";
	                    break;
	                }
	                case "romanLcParenR": {
	                    numFormat = "i";
	                    numSuffix = ")";
	                    break;
	                }
	                case "romanLcParenBoth": {
	                    numFormat = "i";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "romanUcPeriod": {
	                    numFormat = "I";
	                    numSuffix = ".";
	                    break;
	                }
	                case "romanUcParenR": {
	                    numFormat = "I";
	                    numSuffix = ")";
	                    break;
	                }
	                case "romanUcParenBoth": {
	                    numFormat = "I";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "arabicPeriod": {
	                    numFormat = "1";
	                    numSuffix = ".";
	                    break;
	                }
	                case "arabicParenR": {
	                    numFormat = "1";
	                    numSuffix = ")";
	                    break;
	                }
	                case "arabicParenBoth": {
	                    numFormat = "1";
	                    numSuffix = ")";
	                    numPrefix = "(";
	                    break;
	                }
	                case "noNumberListItem": {
	                    break;
	                }
	            }
	            if(numFormat!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-format", "style:num-format", numFormat);
	            }
	            if(numSuffix!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-suffix", "style:num-suffix", numSuffix);
	            }
	            if(numPrefix!=null) {
	                attributes.setValue(Namespaces.STYLE, "num-prefix", "style:num-prefix", numPrefix);
	            }
	        }
	        final Object startAt = ((JSONObject)bulletAttrs).opt(OCKey.START_AT.value());
	        if(startAt!=null) {
    	        if(startAt instanceof Number) {
    	            attributes.setIntValue(Namespaces.TEXT, "start-value", "text:start-value",  ((Number)startAt).intValue());
    	        }
    	        else {
    	            attributes.remove("text:start-value");
    	        }
	        }
	    }
        final Object bulletSizeAttrs = paragraphAttrs.opt(OCKey.BULLET_SIZE.value());
        if(bulletSizeAttrs!=null) {
            if(bulletSizeAttrs instanceof JSONObject) {
                final String type = ((JSONObject)bulletSizeAttrs).optString(OCKey.TYPE.value());
                if("percent".equals(type)) {
                    final Object buSize = ((JSONObject)bulletSizeAttrs).opt(OCKey.SIZE.value());
                    if(buSize!=null) {
                        if(buSize instanceof Number) {
                            getTextProperties(true).getAttributes().setValue(Namespaces.FO, "font-size", "fo:font-size", Integer.toString(((Number)buSize).intValue())+"%");
                        }
                        else {
                            getTextProperties(true).getAttributes().remove("fo:font-size");
                        }
                    }
                }
            }
            else {
                attributes.remove("fo:font-size");
                // TODO what is "text:bullet-relative-size");
            }
        }
        super.applyPresentationAttrs(styleManager, paragraphAttrs);
    }

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
        final Integer listLevel = getListLevel(0);
		if(listLevel>=1&&listLevel<=10) {
			TextListStyle.createListLevelDefinition(this, attrs, listLevel);
		}
	}

	@Override
	public String getQName() {
		return "text:list-level-style-number";
	}
	@Override
	public String getLocalName() {
		return "list-level-style-number";
	}

	@Override
	public String getNamespace() {
		return Namespaces.TEXT;
	}
}
